# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from libica.openapi.libconsole.api_client import ApiClient
from libica.openapi.libconsole.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TokensApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_token(self, **kwargs):  # noqa: E501
        """Creates a JWT token to call IAP services.  # noqa: E501

        This endpoint creates a JWT token to call IAP services. Authorization can be a Bearer psToken,  Basic Base64 encoded username:password or Basic with apiKey.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_token(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str x_api_key: Api Key can be passed in header to generate a JWT.
        :param str client_id: Optionally pass client Id from calling app to set as authorized party on JWT.
        :param str api_key: OBSOLETE: api key should now be passed as as an X-API-Key header.
        :param str domain: Optionally pass the domain name you are logging into
        :param str data: Data is a custom meta data field that will be applied to the session field in the JWT payload.
        :param list[str] scopes: Scopes can be passed in during token generation to limit the token to particular scopes.
        :param str cwid: Set the current workgroup on the token. Used for aligning resources to a workgroup.
        :param str cid: Set the current context on the token. Used for aligning resources to a context.
        :param bool return_session_token: By default, this endpoint returns a JWT token. You can specify returnSessionToken=true to get an Illumina psToken instead.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_token_with_http_info(**kwargs)  # noqa: E501

    def create_token_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a JWT token to call IAP services.  # noqa: E501

        This endpoint creates a JWT token to call IAP services. Authorization can be a Bearer psToken,  Basic Base64 encoded username:password or Basic with apiKey.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_token_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str x_api_key: Api Key can be passed in header to generate a JWT.
        :param str client_id: Optionally pass client Id from calling app to set as authorized party on JWT.
        :param str api_key: OBSOLETE: api key should now be passed as as an X-API-Key header.
        :param str domain: Optionally pass the domain name you are logging into
        :param str data: Data is a custom meta data field that will be applied to the session field in the JWT payload.
        :param list[str] scopes: Scopes can be passed in during token generation to limit the token to particular scopes.
        :param str cwid: Set the current workgroup on the token. Used for aligning resources to a workgroup.
        :param str cid: Set the current context on the token. Used for aligning resources to a context.
        :param bool return_session_token: By default, this endpoint returns a JWT token. You can specify returnSessionToken=true to get an Illumina psToken instead.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TokenResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'x_api_key',
            'client_id',
            'api_key',
            'domain',
            'data',
            'scopes',
            'cwid',
            'cid',
            'return_session_token'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_token" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'client_id' in local_var_params and local_var_params['client_id'] is not None:  # noqa: E501
            query_params.append(('clientId', local_var_params['client_id']))  # noqa: E501
        if 'api_key' in local_var_params and local_var_params['api_key'] is not None:  # noqa: E501
            query_params.append(('api_key', local_var_params['api_key']))  # noqa: E501
        if 'domain' in local_var_params and local_var_params['domain'] is not None:  # noqa: E501
            query_params.append(('domain', local_var_params['domain']))  # noqa: E501
        if 'data' in local_var_params and local_var_params['data'] is not None:  # noqa: E501
            query_params.append(('data', local_var_params['data']))  # noqa: E501
        if 'scopes' in local_var_params and local_var_params['scopes'] is not None:  # noqa: E501
            query_params.append(('scopes', local_var_params['scopes']))  # noqa: E501
            collection_formats['scopes'] = 'csv'  # noqa: E501
        if 'cwid' in local_var_params and local_var_params['cwid'] is not None:  # noqa: E501
            query_params.append(('cwid', local_var_params['cwid']))  # noqa: E501
        if 'cid' in local_var_params and local_var_params['cid'] is not None:  # noqa: E501
            query_params.append(('cid', local_var_params['cid']))  # noqa: E501
        if 'return_session_token' in local_var_params and local_var_params['return_session_token'] is not None:  # noqa: E501
            query_params.append(('returnSessionToken', local_var_params['return_session_token']))  # noqa: E501

        header_params = {}
        if 'x_api_key' in local_var_params:
            header_params['X-API-Key'] = local_var_params['x_api_key']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tokens', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_token_details(self, **kwargs):  # noqa: E501
        """Get current tokens info require authorization Bearer token  # noqa: E501

        Get token details  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_token_details(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TokenDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_token_details_with_http_info(**kwargs)  # noqa: E501

    def get_token_details_with_http_info(self, **kwargs):  # noqa: E501
        """Get current tokens info require authorization Bearer token  # noqa: E501

        Get token details  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_token_details_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TokenDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_token_details" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tokens/details', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenDetailResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def refresh_token(self, **kwargs):  # noqa: E501
        """Refresh session psToken.  # noqa: E501

        This endpoint extends the session for the psToken.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.refresh_token(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AccessTokenRequest body: Access token request accepts a psToken in the access_token field in the body of the request.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.refresh_token_with_http_info(**kwargs)  # noqa: E501

    def refresh_token_with_http_info(self, **kwargs):  # noqa: E501
        """Refresh session psToken.  # noqa: E501

        This endpoint extends the session for the psToken.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.refresh_token_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AccessTokenRequest body: Access token request accepts a psToken in the access_token field in the body of the request.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TokenResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method refresh_token" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tokens:refresh', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revoke_token(self, **kwargs):  # noqa: E501
        """Revokes an access token.  # noqa: E501

        This endpoint revokes the access token that is passed in.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revoke_token(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AccessTokenRequest body: Access token request accepts either a psToken or a JWT in the access_token field in the body of the request.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.revoke_token_with_http_info(**kwargs)  # noqa: E501

    def revoke_token_with_http_info(self, **kwargs):  # noqa: E501
        """Revokes an access token.  # noqa: E501

        This endpoint revokes the access token that is passed in.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revoke_token_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AccessTokenRequest body: Access token request accepts either a psToken or a JWT in the access_token field in the body of the request.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revoke_token" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tokens', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Event Notification Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libens
from libica.openapi.libens.api.subscriptions_api import SubscriptionsApi  # noqa: E501
from libica.openapi.libens.rest import ApiException


class TestSubscriptionsApi(unittest.TestCase):
    """SubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libens.api.subscriptions_api.SubscriptionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_subscription(self):
        """Test case for create_subscription

        Creates a subscription to an event type and defines how those events get delivered.  # noqa: E501
        """
        pass

    def test_disable_subscription(self):
        """Test case for disable_subscription

        Given a subscription id, disables the specified subscription.  # noqa: E501
        """
        pass

    def test_get_subscription(self):
        """Test case for get_subscription

        Given a subscription id, returns information about that subscription.  # noqa: E501
        """
        pass

    def test_list_subscriptions(self):
        """Test case for list_subscriptions

        Get a list of subscriptions.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libwes
from libica.openapi.libwes.models.workflow_connection import WorkflowConnection  # noqa: E501
from libica.openapi.libwes.rest import ApiException

class TestWorkflowConnection(unittest.TestCase):
    """WorkflowConnection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WorkflowConnection
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libwes.models.workflow_connection.WorkflowConnection()  # noqa: E501
        if include_optional :
            return WorkflowConnection(
                name = '0', 
                type = '0', 
                host = 'https://api.myhost.com/v1/', 
                host_validation_regex = '0', 
                credentials = '0', 
                options = '0', 
                auto_disable_url = '0', 
                auto_disable_http_method = '0'
            )
        else :
            return WorkflowConnection(
                name = '0',
        )

    def testWorkflowConnection(self):
        """Test WorkflowConnection"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libconsole
from libica.openapi.libconsole.api.usages_api import UsagesApi  # noqa: E501
from libica.openapi.libconsole.rest import ApiException


class TestUsagesApi(unittest.TestCase):
    """UsagesApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libconsole.api.usages_api.UsagesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_usage(self):
        """Test case for get_usage

        Get current tenant's usage detail by period.  Default returns current period usage data.   # noqa: E501
        """
        pass

    def test_get_usage_details(self):
        """Test case for get_usage_details

        Get current tenant's usage detail by period.  Default returns current period usage data.   # noqa: E501
        """
        pass

    def test_get_usage_periods(self):
        """Test case for get_usage_periods

        Get periods detail info   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from libica.openapi.libgds.models.awss3_object_store_setting import AWSS3ObjectStoreSetting
from libica.openapi.libgds.models.archive_statuses import ArchiveStatuses
from libica.openapi.libgds.models.aws_s3_temporary_upload_credentials import AwsS3TemporaryUploadCredentials
from libica.openapi.libgds.models.complete_session_request import CompleteSessionRequest
from libica.openapi.libgds.models.create_file_request import CreateFileRequest
from libica.openapi.libgds.models.create_folder_request import CreateFolderRequest
from libica.openapi.libgds.models.create_volume_configuration_request import CreateVolumeConfigurationRequest
from libica.openapi.libgds.models.create_volume_request import CreateVolumeRequest
from libica.openapi.libgds.models.create_volume_response import CreateVolumeResponse
from libica.openapi.libgds.models.error_response import ErrorResponse
from libica.openapi.libgds.models.file_archive_request import FileArchiveRequest
from libica.openapi.libgds.models.file_archive_storage_tier import FileArchiveStorageTier
from libica.openapi.libgds.models.file_list_response import FileListResponse
from libica.openapi.libgds.models.file_response import FileResponse
from libica.openapi.libgds.models.file_unarchive_request import FileUnarchiveRequest
from libica.openapi.libgds.models.file_writeable_response import FileWriteableResponse
from libica.openapi.libgds.models.folder_archive_request import FolderArchiveRequest
from libica.openapi.libgds.models.folder_archive_storage_tier import FolderArchiveStorageTier
from libica.openapi.libgds.models.folder_copy_operation_parameters import FolderCopyOperationParameters
from libica.openapi.libgds.models.folder_copy_request import FolderCopyRequest
from libica.openapi.libgds.models.folder_list_response import FolderListResponse
from libica.openapi.libgds.models.folder_response import FolderResponse
from libica.openapi.libgds.models.folder_unarchive_request import FolderUnarchiveRequest
from libica.openapi.libgds.models.folder_update_request import FolderUpdateRequest
from libica.openapi.libgds.models.folder_writeable_response import FolderWriteableResponse
from libica.openapi.libgds.models.job_operation_parameters import JobOperationParameters
from libica.openapi.libgds.models.job_operation_type import JobOperationType
from libica.openapi.libgds.models.job_progress_status import JobProgressStatus
from libica.openapi.libgds.models.job_response import JobResponse
from libica.openapi.libgds.models.job_status import JobStatus
from libica.openapi.libgds.models.object_store_access import ObjectStoreAccess
from libica.openapi.libgds.models.object_store_settings import ObjectStoreSettings
from libica.openapi.libgds.models.session_response import SessionResponse
from libica.openapi.libgds.models.session_status import SessionStatus
from libica.openapi.libgds.models.storage_tier import StorageTier
from libica.openapi.libgds.models.update_file_request import UpdateFileRequest
from libica.openapi.libgds.models.volume_configuration_list_response import VolumeConfigurationListResponse
from libica.openapi.libgds.models.volume_configuration_online_status import VolumeConfigurationOnlineStatus
from libica.openapi.libgds.models.volume_configuration_response import VolumeConfigurationResponse
from libica.openapi.libgds.models.volume_list_response import VolumeListResponse
from libica.openapi.libgds.models.volume_response import VolumeResponse



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libconsole
from libica.openapi.libconsole.models.usage_response import UsageResponse  # noqa: E501
from libica.openapi.libconsole.rest import ApiException

class TestUsageResponse(unittest.TestCase):
    """UsageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UsageResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libconsole.models.usage_response.UsageResponse()  # noqa: E501
        if include_optional :
            return UsageResponse(
                items = [
                    libica.openapi.libconsole.models.period_usage_summary.PeriodUsageSummary(
                        start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        i_credit = 56, 
                        total_usages = [
                            libica.openapi.libconsole.models.product_usage.ProductUsage(
                                type = '0', 
                                amount = 1.337, 
                                unit = '0', 
                                i_credit = 1.337, )
                            ], 
                        user_aggregated_usages = [
                            libica.openapi.libconsole.models.user_aggregated_usage.UserAggregatedUsage(
                                user = libica.openapi.libconsole.models.user.User(
                                    full_name = '0', 
                                    user_name = '0', 
                                    domain = libica.openapi.libconsole.models.domain.Domain(
                                        id = '0', 
                                        name = '0', ), 
                                    type = '0', ), 
                                i_credit = 1.337, 
                                usages = [
                                    libica.openapi.libconsole.models.product_usage.ProductUsage(
                                        type = '0', 
                                        amount = 1.337, 
                                        unit = '0', 
                                        i_credit = 1.337, )
                                    ], )
                            ], )
                    ]
            )
        else :
            return UsageResponse(
        )

    def testUsageResponse(self):
        """Test UsageResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



import logging

handler = logging.StreamHandler()
formatter = logging.Formatter('%(asctime)s %(name)-12s %(levelname)-8s %(message)s')
handler.setFormatter(formatter)
_logger = logging.getLogger()
_logger.addHandler(handler)
_logger.setLevel(logging.DEBUG)

MOCK_EP = "http://localhost"



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libwes.configuration import Configuration


class WorkflowSignalCompact(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'urn': 'str',
        'href': 'str',
        'send_heartbeat_href': 'str',
        'send_success_response_href': 'str',
        'send_failure_response_href': 'str',
        'name': 'str',
        'status': 'str',
        'type': 'str',
        'description': 'str',
        'inputs': 'object',
        'workflow_run': 'WorkflowRunCompact',
        'timeout_seconds': 'int',
        'result': 'object',
        'error': 'str',
        'error_cause': 'str',
        'created_by_client_id': 'str',
        'time_created': 'datetime',
        'time_modified': 'datetime',
        'created_by': 'str',
        'modified_by': 'str',
        'tenant_id': 'str',
        'acl': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'urn': 'urn',
        'href': 'href',
        'send_heartbeat_href': 'sendHeartbeatHref',
        'send_success_response_href': 'sendSuccessResponseHref',
        'send_failure_response_href': 'sendFailureResponseHref',
        'name': 'name',
        'status': 'status',
        'type': 'type',
        'description': 'description',
        'inputs': 'inputs',
        'workflow_run': 'workflowRun',
        'timeout_seconds': 'timeoutSeconds',
        'result': 'result',
        'error': 'error',
        'error_cause': 'errorCause',
        'created_by_client_id': 'createdByClientId',
        'time_created': 'timeCreated',
        'time_modified': 'timeModified',
        'created_by': 'createdBy',
        'modified_by': 'modifiedBy',
        'tenant_id': 'tenantId',
        'acl': 'acl'
    }

    def __init__(self, id=None, urn=None, href=None, send_heartbeat_href=None, send_success_response_href=None, send_failure_response_href=None, name=None, status=None, type=None, description=None, inputs=None, workflow_run=None, timeout_seconds=None, result=None, error=None, error_cause=None, created_by_client_id=None, time_created=None, time_modified=None, created_by=None, modified_by=None, tenant_id=None, acl=None, local_vars_configuration=None):  # noqa: E501
        """WorkflowSignalCompact - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._urn = None
        self._href = None
        self._send_heartbeat_href = None
        self._send_success_response_href = None
        self._send_failure_response_href = None
        self._name = None
        self._status = None
        self._type = None
        self._description = None
        self._inputs = None
        self._workflow_run = None
        self._timeout_seconds = None
        self._result = None
        self._error = None
        self._error_cause = None
        self._created_by_client_id = None
        self._time_created = None
        self._time_modified = None
        self._created_by = None
        self._modified_by = None
        self._tenant_id = None
        self._acl = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if urn is not None:
            self.urn = urn
        if href is not None:
            self.href = href
        if send_heartbeat_href is not None:
            self.send_heartbeat_href = send_heartbeat_href
        if send_success_response_href is not None:
            self.send_success_response_href = send_success_response_href
        if send_failure_response_href is not None:
            self.send_failure_response_href = send_failure_response_href
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if inputs is not None:
            self.inputs = inputs
        if workflow_run is not None:
            self.workflow_run = workflow_run
        if timeout_seconds is not None:
            self.timeout_seconds = timeout_seconds
        if result is not None:
            self.result = result
        if error is not None:
            self.error = error
        if error_cause is not None:
            self.error_cause = error_cause
        if created_by_client_id is not None:
            self.created_by_client_id = created_by_client_id
        if time_created is not None:
            self.time_created = time_created
        if time_modified is not None:
            self.time_modified = time_modified
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if acl is not None:
            self.acl = acl

    @property
    def id(self):
        """Gets the id of this WorkflowSignalCompact.  # noqa: E501

        Unique resource ID  # noqa: E501

        :return: The id of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WorkflowSignalCompact.

        Unique resource ID  # noqa: E501

        :param id: The id of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def urn(self):
        """Gets the urn of this WorkflowSignalCompact.  # noqa: E501

        URN of the resource  # noqa: E501

        :return: The urn of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this WorkflowSignalCompact.

        URN of the resource  # noqa: E501

        :param urn: The urn of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def href(self):
        """Gets the href of this WorkflowSignalCompact.  # noqa: E501

        HREF to the resource  # noqa: E501

        :return: The href of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this WorkflowSignalCompact.

        HREF to the resource  # noqa: E501

        :param href: The href of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def send_heartbeat_href(self):
        """Gets the send_heartbeat_href of this WorkflowSignalCompact.  # noqa: E501

        HREF to send a heartbeat to a workflow signal  # noqa: E501

        :return: The send_heartbeat_href of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._send_heartbeat_href

    @send_heartbeat_href.setter
    def send_heartbeat_href(self, send_heartbeat_href):
        """Sets the send_heartbeat_href of this WorkflowSignalCompact.

        HREF to send a heartbeat to a workflow signal  # noqa: E501

        :param send_heartbeat_href: The send_heartbeat_href of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._send_heartbeat_href = send_heartbeat_href

    @property
    def send_success_response_href(self):
        """Gets the send_success_response_href of this WorkflowSignalCompact.  # noqa: E501

        HREF to succeed a workflow signal  # noqa: E501

        :return: The send_success_response_href of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._send_success_response_href

    @send_success_response_href.setter
    def send_success_response_href(self, send_success_response_href):
        """Sets the send_success_response_href of this WorkflowSignalCompact.

        HREF to succeed a workflow signal  # noqa: E501

        :param send_success_response_href: The send_success_response_href of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._send_success_response_href = send_success_response_href

    @property
    def send_failure_response_href(self):
        """Gets the send_failure_response_href of this WorkflowSignalCompact.  # noqa: E501

        HREF to fail a workflow signal  # noqa: E501

        :return: The send_failure_response_href of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._send_failure_response_href

    @send_failure_response_href.setter
    def send_failure_response_href(self, send_failure_response_href):
        """Sets the send_failure_response_href of this WorkflowSignalCompact.

        HREF to fail a workflow signal  # noqa: E501

        :param send_failure_response_href: The send_failure_response_href of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._send_failure_response_href = send_failure_response_href

    @property
    def name(self):
        """Gets the name of this WorkflowSignalCompact.  # noqa: E501

        Unique name of the signal  # noqa: E501

        :return: The name of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowSignalCompact.

        Unique name of the signal  # noqa: E501

        :param name: The name of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this WorkflowSignalCompact.  # noqa: E501

        Current status of the signal  # noqa: E501

        :return: The status of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WorkflowSignalCompact.

        Current status of the signal  # noqa: E501

        :param status: The status of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def type(self):
        """Gets the type of this WorkflowSignalCompact.  # noqa: E501

        User-defined type associated with the signal  # noqa: E501

        :return: The type of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this WorkflowSignalCompact.

        User-defined type associated with the signal  # noqa: E501

        :param type: The type of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def description(self):
        """Gets the description of this WorkflowSignalCompact.  # noqa: E501

        Description of the signal  # noqa: E501

        :return: The description of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WorkflowSignalCompact.

        Description of the signal  # noqa: E501

        :param description: The description of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def inputs(self):
        """Gets the inputs of this WorkflowSignalCompact.  # noqa: E501

        Inputs defined by the originating WaitForSignal state, in JSON.  # noqa: E501

        :return: The inputs of this WorkflowSignalCompact.  # noqa: E501
        :rtype: object
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this WorkflowSignalCompact.

        Inputs defined by the originating WaitForSignal state, in JSON.  # noqa: E501

        :param inputs: The inputs of this WorkflowSignalCompact.  # noqa: E501
        :type: object
        """

        self._inputs = inputs

    @property
    def workflow_run(self):
        """Gets the workflow_run of this WorkflowSignalCompact.  # noqa: E501


        :return: The workflow_run of this WorkflowSignalCompact.  # noqa: E501
        :rtype: WorkflowRunCompact
        """
        return self._workflow_run

    @workflow_run.setter
    def workflow_run(self, workflow_run):
        """Sets the workflow_run of this WorkflowSignalCompact.


        :param workflow_run: The workflow_run of this WorkflowSignalCompact.  # noqa: E501
        :type: WorkflowRunCompact
        """

        self._workflow_run = workflow_run

    @property
    def timeout_seconds(self):
        """Gets the timeout_seconds of this WorkflowSignalCompact.  # noqa: E501

        Signal timeout in seconds. The Signal will timeout if a heartbeat, succeed or fail is not received in this time interval.  # noqa: E501

        :return: The timeout_seconds of this WorkflowSignalCompact.  # noqa: E501
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """Sets the timeout_seconds of this WorkflowSignalCompact.

        Signal timeout in seconds. The Signal will timeout if a heartbeat, succeed or fail is not received in this time interval.  # noqa: E501

        :param timeout_seconds: The timeout_seconds of this WorkflowSignalCompact.  # noqa: E501
        :type: int
        """

        self._timeout_seconds = timeout_seconds

    @property
    def result(self):
        """Gets the result of this WorkflowSignalCompact.  # noqa: E501

        The result of a successful signalling action in JSON.  # noqa: E501

        :return: The result of this WorkflowSignalCompact.  # noqa: E501
        :rtype: object
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this WorkflowSignalCompact.

        The result of a successful signalling action in JSON.  # noqa: E501

        :param result: The result of this WorkflowSignalCompact.  # noqa: E501
        :type: object
        """

        self._result = result

    @property
    def error(self):
        """Gets the error of this WorkflowSignalCompact.  # noqa: E501

        The error of a failed signal.  # noqa: E501

        :return: The error of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this WorkflowSignalCompact.

        The error of a failed signal.  # noqa: E501

        :param error: The error of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def error_cause(self):
        """Gets the error_cause of this WorkflowSignalCompact.  # noqa: E501

        The error cause of a failed signal.  # noqa: E501

        :return: The error_cause of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._error_cause

    @error_cause.setter
    def error_cause(self, error_cause):
        """Sets the error_cause of this WorkflowSignalCompact.

        The error cause of a failed signal.  # noqa: E501

        :param error_cause: The error_cause of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._error_cause = error_cause

    @property
    def created_by_client_id(self):
        """Gets the created_by_client_id of this WorkflowSignalCompact.  # noqa: E501

        Client ID of the Origin Request  # noqa: E501

        :return: The created_by_client_id of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._created_by_client_id

    @created_by_client_id.setter
    def created_by_client_id(self, created_by_client_id):
        """Sets the created_by_client_id of this WorkflowSignalCompact.

        Client ID of the Origin Request  # noqa: E501

        :param created_by_client_id: The created_by_client_id of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._created_by_client_id = created_by_client_id

    @property
    def time_created(self):
        """Gets the time_created of this WorkflowSignalCompact.  # noqa: E501

        Time (in UTC) the resource was created  # noqa: E501

        :return: The time_created of this WorkflowSignalCompact.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this WorkflowSignalCompact.

        Time (in UTC) the resource was created  # noqa: E501

        :param time_created: The time_created of this WorkflowSignalCompact.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def time_modified(self):
        """Gets the time_modified of this WorkflowSignalCompact.  # noqa: E501

        Time (in UTC) the resource was modified  # noqa: E501

        :return: The time_modified of this WorkflowSignalCompact.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this WorkflowSignalCompact.

        Time (in UTC) the resource was modified  # noqa: E501

        :param time_modified: The time_modified of this WorkflowSignalCompact.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    @property
    def created_by(self):
        """Gets the created_by of this WorkflowSignalCompact.  # noqa: E501

        User that created the resource  # noqa: E501

        :return: The created_by of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this WorkflowSignalCompact.

        User that created the resource  # noqa: E501

        :param created_by: The created_by of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this WorkflowSignalCompact.  # noqa: E501

        User that modified the resource  # noqa: E501

        :return: The modified_by of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this WorkflowSignalCompact.

        User that modified the resource  # noqa: E501

        :param modified_by: The modified_by of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def tenant_id(self):
        """Gets the tenant_id of this WorkflowSignalCompact.  # noqa: E501

        Tenant ID the resource belongs to  # noqa: E501

        :return: The tenant_id of this WorkflowSignalCompact.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this WorkflowSignalCompact.

        Tenant ID the resource belongs to  # noqa: E501

        :param tenant_id: The tenant_id of this WorkflowSignalCompact.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                tenant_id is not None and len(tenant_id) > 255):
            raise ValueError("Invalid value for `tenant_id`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                tenant_id is not None and len(tenant_id) < 0):
            raise ValueError("Invalid value for `tenant_id`, length must be greater than or equal to `0`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def acl(self):
        """Gets the acl of this WorkflowSignalCompact.  # noqa: E501

        Access control list of the resource  # noqa: E501

        :return: The acl of this WorkflowSignalCompact.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this WorkflowSignalCompact.

        Access control list of the resource  # noqa: E501

        :param acl: The acl of this WorkflowSignalCompact.  # noqa: E501
        :type: list[str]
        """

        self._acl = acl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowSignalCompact):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowSignalCompact):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from libica.openapi.libgds.api.files_api import FilesApi
from libica.openapi.libgds.api.folders_api import FoldersApi
from libica.openapi.libgds.api.volume_configurations_api import VolumeConfigurationsApi
from libica.openapi.libgds.api.volumes_api import VolumesApi



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libgds
from libica.openapi.libgds.api.files_api import FilesApi  # noqa: E501
from libica.openapi.libgds.rest import ApiException


class TestFilesApi(unittest.TestCase):
    """FilesApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libgds.api.files_api.FilesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_file(self):
        """Test case for archive_file

        Archive a file  # noqa: E501
        """
        pass

    def test_create_file(self):
        """Test case for create_file

        Create a file entry in GDS and get temporary credentials for upload  # noqa: E501
        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        Permanently delete a file  # noqa: E501
        """
        pass

    def test_get_file(self):
        """Test case for get_file

        Get details about a file, including a pre-signed URL for download  # noqa: E501
        """
        pass

    def test_list_files(self):
        """Test case for list_files

        Get a list of files  # noqa: E501
        """
        pass

    def test_unarchive_file(self):
        """Test case for unarchive_file

        Unarchive a file  # noqa: E501
        """
        pass

    def test_update_file(self):
        """Test case for update_file

        Update a file entry in GDS and get temporary credentials for upload  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libwes
from libica.openapi.libwes.api.workflow_runs_api import WorkflowRunsApi  # noqa: E501
from libica.openapi.libwes.rest import ApiException


class TestWorkflowRunsApi(unittest.TestCase):
    """WorkflowRunsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libwes.api.workflow_runs_api.WorkflowRunsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_workflow_run(self):
        """Test case for abort_workflow_run

        Abort a workflow run  # noqa: E501
        """
        pass

    def test_get_workflow_run(self):
        """Test case for get_workflow_run

        Get the details of a workflow run  # noqa: E501
        """
        pass

    def test_list_workflow_run_history(self):
        """Test case for list_workflow_run_history

        Get a list of workflow run history events  # noqa: E501
        """
        pass

    def test_list_workflow_runs(self):
        """Test case for list_workflow_runs

        Get a list of workflow runs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from libica.openapi.libconsole.api.accounts_api import AccountsApi
from libica.openapi.libconsole.api.health_api import HealthApi
from libica.openapi.libconsole.api.projects_api import ProjectsApi
from libica.openapi.libconsole.api.regions_api import RegionsApi
from libica.openapi.libconsole.api.tokens_api import TokensApi
from libica.openapi.libconsole.api.usages_api import UsagesApi
from libica.openapi.libconsole.api.workgroups_api import WorkgroupsApi

# import ApiClient
from libica.openapi.libconsole.api_client import ApiClient
from libica.openapi.libconsole.configuration import Configuration
from libica.openapi.libconsole.exceptions import OpenApiException
from libica.openapi.libconsole.exceptions import ApiTypeError
from libica.openapi.libconsole.exceptions import ApiValueError
from libica.openapi.libconsole.exceptions import ApiKeyError
from libica.openapi.libconsole.exceptions import ApiException
# import models into sdk package
from libica.openapi.libconsole.models.access_token_request import AccessTokenRequest
from libica.openapi.libconsole.models.account_response import AccountResponse
from libica.openapi.libconsole.models.domain import Domain
from libica.openapi.libconsole.models.error_response import ErrorResponse
from libica.openapi.libconsole.models.health_check_statuses import HealthCheckStatuses
from libica.openapi.libconsole.models.period_usage_summary import PeriodUsageSummary
from libica.openapi.libconsole.models.product_usage import ProductUsage
from libica.openapi.libconsole.models.project import Project
from libica.openapi.libconsole.models.project_paged_items import ProjectPagedItems
from libica.openapi.libconsole.models.region import Region
from libica.openapi.libconsole.models.service_health_response import ServiceHealthResponse
from libica.openapi.libconsole.models.system_health_response import SystemHealthResponse
from libica.openapi.libconsole.models.token_detail_response import TokenDetailResponse
from libica.openapi.libconsole.models.token_response import TokenResponse
from libica.openapi.libconsole.models.usage_response import UsageResponse
from libica.openapi.libconsole.models.user import User
from libica.openapi.libconsole.models.user_aggregated_usage import UserAggregatedUsage
from libica.openapi.libconsole.models.workgroup import Workgroup
from libica.openapi.libconsole.models.workgroup_response import WorkgroupResponse




# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libwes
from libica.openapi.libwes.models.workflow_signal_compact import WorkflowSignalCompact  # noqa: E501
from libica.openapi.libwes.rest import ApiException

class TestWorkflowSignalCompact(unittest.TestCase):
    """WorkflowSignalCompact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WorkflowSignalCompact
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libwes.models.workflow_signal_compact.WorkflowSignalCompact()  # noqa: E501
        if include_optional :
            return WorkflowSignalCompact(
                id = '0', 
                urn = '0', 
                href = '0', 
                send_heartbeat_href = '0', 
                send_success_response_href = '0', 
                send_failure_response_href = '0', 
                name = '0', 
                status = '0', 
                type = '0', 
                description = '0', 
                inputs = None, 
                workflow_run = libica.openapi.libwes.models.workflow_run_compact.WorkflowRunCompact(
                    id = '0', 
                    urn = '0', 
                    href = '0', 
                    name = '0', 
                    time_started = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    time_stopped = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    status = '0', 
                    status_summary = '0', 
                    error = '0', 
                    error_cause = '0', 
                    workflow_version = libica.openapi.libwes.models.workflow_version_compact.WorkflowVersionCompact(
                        id = '0', 
                        urn = '0', 
                        href = '0', 
                        version = '0', 
                        category = '0', 
                        description = '0', 
                        language = libica.openapi.libwes.models.workflow_language.WorkflowLanguage(
                            name = '0', 
                            version = '0', ), 
                        status = '0', 
                        created_by_client_id = '0', 
                        time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = '0', 
                        modified_by = '0', 
                        tenant_id = '0', 
                        acl = [
                            '0'
                            ], ), 
                    created_by_client_id = '0', 
                    time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    created_by = '0', 
                    modified_by = '0', 
                    tenant_id = '0', 
                    acl = [
                        '0'
                        ], ), 
                timeout_seconds = 56, 
                result = None, 
                error = '0', 
                error_cause = '0', 
                created_by_client_id = '0', 
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                created_by = '0', 
                modified_by = '0', 
                tenant_id = '0', 
                acl = [
                    '0'
                    ]
            )
        else :
            return WorkflowSignalCompact(
        )

    def testWorkflowSignalCompact(self):
        """Test WorkflowSignalCompact"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libwes
from libica.openapi.libwes.api.workflows_api import WorkflowsApi  # noqa: E501
from libica.openapi.libwes.rest import ApiException


class TestWorkflowsApi(unittest.TestCase):
    """WorkflowsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libwes.api.workflows_api.WorkflowsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_workflow(self):
        """Test case for create_workflow

        Create a workflow  # noqa: E501
        """
        pass

    def test_get_workflow(self):
        """Test case for get_workflow

        Get the details of a workflow  # noqa: E501
        """
        pass

    def test_list_workflows(self):
        """Test case for list_workflows

        Get a list of workflows  # noqa: E501
        """
        pass

    def test_update_workflow(self):
        """Test case for update_workflow

        Update an existing workflow  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libtes
from libica.openapi.libtes.api.task_versions_api import TaskVersionsApi  # noqa: E501
from libica.openapi.libtes.rest import ApiException


class TestTaskVersionsApi(unittest.TestCase):
    """TaskVersionsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libtes.api.task_versions_api.TaskVersionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_task_version(self):
        """Test case for create_task_version

        Create a task version  # noqa: E501
        """
        pass

    def test_get_task_version(self):
        """Test case for get_task_version

        Get the details of a task version  # noqa: E501
        """
        pass

    def test_launch_task_run(self):
        """Test case for launch_task_run

        Launch a task version  # noqa: E501
        """
        pass

    def test_list_task_versions(self):
        """Test case for list_task_versions

        Get a list of versions  # noqa: E501
        """
        pass

    def test_update_task_version(self):
        """Test case for update_task_version

        Update task version properties  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class CreateVolumeRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'volume_configuration_name': 'str',
        'root_key_prefix': 'str'
    }

    attribute_map = {
        'name': 'name',
        'volume_configuration_name': 'volumeConfigurationName',
        'root_key_prefix': 'rootKeyPrefix'
    }

    def __init__(self, name=None, volume_configuration_name=None, root_key_prefix=None, local_vars_configuration=None):  # noqa: E501
        """CreateVolumeRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._volume_configuration_name = None
        self._root_key_prefix = None
        self.discriminator = None

        self.name = name
        if volume_configuration_name is not None:
            self.volume_configuration_name = volume_configuration_name
        if root_key_prefix is not None:
            self.root_key_prefix = root_key_prefix

    @property
    def name(self):
        """Gets the name of this CreateVolumeRequest.  # noqa: E501

        Name for the volume  # noqa: E501

        :return: The name of this CreateVolumeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateVolumeRequest.

        Name for the volume  # noqa: E501

        :param name: The name of this CreateVolumeRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def volume_configuration_name(self):
        """Gets the volume_configuration_name of this CreateVolumeRequest.  # noqa: E501

        Unique name of the volume configuration to use  # noqa: E501

        :return: The volume_configuration_name of this CreateVolumeRequest.  # noqa: E501
        :rtype: str
        """
        return self._volume_configuration_name

    @volume_configuration_name.setter
    def volume_configuration_name(self, volume_configuration_name):
        """Sets the volume_configuration_name of this CreateVolumeRequest.

        Unique name of the volume configuration to use  # noqa: E501

        :param volume_configuration_name: The volume_configuration_name of this CreateVolumeRequest.  # noqa: E501
        :type: str
        """

        self._volume_configuration_name = volume_configuration_name

    @property
    def root_key_prefix(self):
        """Gets the root_key_prefix of this CreateVolumeRequest.  # noqa: E501

        The base bucket location for volumes associated with custom VolumeConfigurations. If not provided, the given volume Name is used.  If provided, it must start with the VolumeConfiguration's keyprefix and end with a /.  To create a volume representing the root of a bucket, use the value '/'.  # noqa: E501

        :return: The root_key_prefix of this CreateVolumeRequest.  # noqa: E501
        :rtype: str
        """
        return self._root_key_prefix

    @root_key_prefix.setter
    def root_key_prefix(self, root_key_prefix):
        """Sets the root_key_prefix of this CreateVolumeRequest.

        The base bucket location for volumes associated with custom VolumeConfigurations. If not provided, the given volume Name is used.  If provided, it must start with the VolumeConfiguration's keyprefix and end with a /.  To create a volume representing the root of a bucket, use the value '/'.  # noqa: E501

        :param root_key_prefix: The root_key_prefix of this CreateVolumeRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                root_key_prefix is not None and not re.search(r'^(\/)$|^([^\/].*[\/])$', root_key_prefix)):  # noqa: E501
            raise ValueError(r"Invalid value for `root_key_prefix`, must be a follow pattern or equal to `/^(\/)$|^([^\/].*[\/])$/`")  # noqa: E501

        self._root_key_prefix = root_key_prefix

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVolumeRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateVolumeRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libconsole
from libica.openapi.libconsole.api.projects_api import ProjectsApi  # noqa: E501
from libica.openapi.libconsole.rest import ApiException


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libconsole.api.projects_api.ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_list_projects(self):
        """Test case for list_projects

        Get a list of available projects. Requires user authorization Bearer token.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.environment import Environment  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestEnvironment(unittest.TestCase):
    """Environment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Environment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.environment.Environment()  # noqa: E501
        if include_optional :
            return Environment(
                variables = {
                    'key' : '0'
                    }, 
                resources = libica.openapi.libtes.models.resources.Resources(
                    type = '0', 
                    size = '0', 
                    cpu_cores = 1.337, 
                    memory_gb = 1.337, 
                    hardware = [
                        '0'
                        ], 
                    tier = '0', ), 
                input_stream_settings = libica.openapi.libtes.models.input_stream_settings.InputStreamSettings(
                    access_pattern = 'sequential', 
                    cache_size_gb = 5E+1, 
                    block_size_mb = 0, 
                    prefetch_blocks = 0, )
            )
        else :
            return Environment(
        )

    def testEnvironment(self):
        """Test Environment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from libica.openapi.libgds.api_client import ApiClient
from libica.openapi.libgds.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class FoldersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_folder(self, folder_id, body, **kwargs):  # noqa: E501
        """Archive a folder  # noqa: E501

        Archives a folder to a lower storage cost tier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_folder(folder_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be archived. (required)
        :param FolderArchiveRequest body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.archive_folder_with_http_info(folder_id, body, **kwargs)  # noqa: E501

    def archive_folder_with_http_info(self, folder_id, body, **kwargs):  # noqa: E501
        """Archive a folder  # noqa: E501

        Archives a folder to a lower storage cost tier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_folder_with_http_info(folder_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be archived. (required)
        :param FolderArchiveRequest body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FolderResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_folder" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `archive_folder`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `archive_folder`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}:archive', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FolderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def complete_folder_session(self, folder_id, session_id, body, **kwargs):  # noqa: E501
        """Complete a folder upload in GDS  # noqa: E501

        Complete a folder upload in GDS.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.complete_folder_session(folder_id, session_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder related to the upload session. (required)
        :param str session_id: The id of the upload session (required)
        :param CompleteSessionRequest body: The request body (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SessionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.complete_folder_session_with_http_info(folder_id, session_id, body, **kwargs)  # noqa: E501

    def complete_folder_session_with_http_info(self, folder_id, session_id, body, **kwargs):  # noqa: E501
        """Complete a folder upload in GDS  # noqa: E501

        Complete a folder upload in GDS.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.complete_folder_session_with_http_info(folder_id, session_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder related to the upload session. (required)
        :param str session_id: The id of the upload session (required)
        :param CompleteSessionRequest body: The request body (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SessionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id',
            'session_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method complete_folder_session" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `complete_folder_session`")  # noqa: E501
        # verify the required parameter 'session_id' is set
        if self.api_client.client_side_validation and ('session_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['session_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `session_id` when calling `complete_folder_session`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `complete_folder_session`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501
        if 'session_id' in local_var_params:
            path_params['sessionId'] = local_var_params['session_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}/sessions/{sessionId}:complete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SessionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def copy_folder(self, folder_id, body, **kwargs):  # noqa: E501
        """Copy a folder  # noqa: E501

        Copy a folder into a target parent folder  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.copy_folder(folder_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be copied. (required)
        :param FolderCopyRequest body: (required)
        :param str tenant_id: Optional parameter to copy from a shared folder in another tenant
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.copy_folder_with_http_info(folder_id, body, **kwargs)  # noqa: E501

    def copy_folder_with_http_info(self, folder_id, body, **kwargs):  # noqa: E501
        """Copy a folder  # noqa: E501

        Copy a folder into a target parent folder  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.copy_folder_with_http_info(folder_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be copied. (required)
        :param FolderCopyRequest body: (required)
        :param str tenant_id: Optional parameter to copy from a shared folder in another tenant
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id',
            'body',
            'tenant_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method copy_folder" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `copy_folder`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `copy_folder`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}:copy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_folder(self, body, **kwargs):  # noqa: E501
        """Create a folder in GDS and receive credentials for upload  # noqa: E501

        Create a folder entry in GDS. Returns temporary credentials for folder upload directly to S3 when the include=objectStoreAccess parameter is used. Volume ID or volume name is required for folder creation. If a folder path is provided and does not exist, GDS automatically creates the folder path in the appropriate account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_folder(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateFolderRequest body: (required)
        :param str include: Comma-separated list of properties to include in the response ([include=[totalItemCount]).Example: include=totalItemCount
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FolderWriteableResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_folder_with_http_info(body, **kwargs)  # noqa: E501

    def create_folder_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create a folder in GDS and receive credentials for upload  # noqa: E501

        Create a folder entry in GDS. Returns temporary credentials for folder upload directly to S3 when the include=objectStoreAccess parameter is used. Volume ID or volume name is required for folder creation. If a folder path is provided and does not exist, GDS automatically creates the folder path in the appropriate account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_folder_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateFolderRequest body: (required)
        :param str include: Comma-separated list of properties to include in the response ([include=[totalItemCount]).Example: include=totalItemCount
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FolderWriteableResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body',
            'include'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_folder" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `create_folder`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FolderWriteableResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_folder(self, folder_id, **kwargs):  # noqa: E501
        """Deletes a folder by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_folder(folder_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be deleted. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_folder_with_http_info(folder_id, **kwargs)  # noqa: E501

    def delete_folder_with_http_info(self, folder_id, **kwargs):  # noqa: E501
        """Deletes a folder by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_folder_with_http_info(folder_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be deleted. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FolderResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_folder" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `delete_folder`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FolderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_folder(self, folder_id, **kwargs):  # noqa: E501
        """Get information about a folder in GDS.  # noqa: E501

        Get information for the specified folder ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_folder(folder_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to retrieve. (required)
        :param str tenant_id: Optional parameter to see shared data in another tenant
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_folder_with_http_info(folder_id, **kwargs)  # noqa: E501

    def get_folder_with_http_info(self, folder_id, **kwargs):  # noqa: E501
        """Get information about a folder in GDS.  # noqa: E501

        Get information for the specified folder ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_folder_with_http_info(folder_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to retrieve. (required)
        :param str tenant_id: Optional parameter to see shared data in another tenant
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FolderResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id',
            'tenant_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_folder" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `get_folder`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FolderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_folder_job(self, folder_id, job_id, **kwargs):  # noqa: E501
        """Get status of a folder job in GDS  # noqa: E501

        Get status of a folder job in GDS.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_folder_job(folder_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder related to the job. (required)
        :param str job_id: The id of the job (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_folder_job_with_http_info(folder_id, job_id, **kwargs)  # noqa: E501

    def get_folder_job_with_http_info(self, folder_id, job_id, **kwargs):  # noqa: E501
        """Get status of a folder job in GDS  # noqa: E501

        Get status of a folder job in GDS.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_folder_job_with_http_info(folder_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder related to the job. (required)
        :param str job_id: The id of the job (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id',
            'job_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_folder_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `get_folder_job`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ('job_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_id` when calling `get_folder_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501
        if 'job_id' in local_var_params:
            path_params['jobId'] = local_var_params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}/jobs/{jobId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_folder_session(self, folder_id, session_id, **kwargs):  # noqa: E501
        """Get status of a folder upload in GDS  # noqa: E501

        Get status of a folder upload in GDS.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_folder_session(folder_id, session_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder related to the upload session. (required)
        :param str session_id: The id of the upload session (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SessionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_folder_session_with_http_info(folder_id, session_id, **kwargs)  # noqa: E501

    def get_folder_session_with_http_info(self, folder_id, session_id, **kwargs):  # noqa: E501
        """Get status of a folder upload in GDS  # noqa: E501

        Get status of a folder upload in GDS.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_folder_session_with_http_info(folder_id, session_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder related to the upload session. (required)
        :param str session_id: The id of the upload session (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SessionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id',
            'session_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_folder_session" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `get_folder_session`")  # noqa: E501
        # verify the required parameter 'session_id' is set
        if self.api_client.client_side_validation and ('session_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['session_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `session_id` when calling `get_folder_session`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501
        if 'session_id' in local_var_params:
            path_params['sessionId'] = local_var_params['session_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}/sessions/{sessionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SessionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_folders(self, **kwargs):  # noqa: E501
        """Get a list of folders  # noqa: E501

        Given a volumeId or volume name, get a list of folders accessible by the JWT. The default sort returned is alphabetical, ascending. The default page size is 10 items  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_folders(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] volume_id: Optional field that specifies comma-separated volume IDs to include in the list
        :param list[str] volume_name: Optional field that specifies comma-separated volume names to include in the list
        :param list[str] path: Optional field that specifies comma-separated paths to include in the list. Value can use wildcards (e.g. /a/b/c/*) or exact matches (e.g. /a/b/c/d/).
        :param str job_statuses: Optional field that specifies comma-separated JobStatuses to include in the list
        :param list[str] acls: Optional field that specifies comma-separated acls to include in the list
        :param bool recursive: Optional field to specify if folders should be returned recursively in and under the specified paths, or only directly in the specified paths
        :param int page_size: START_DESC END_DESC
        :param str page_token: START_DESC END_DESC
        :param str include: START_DESC END_DESC
        :param str tenant_id: Optional parameter to see shared data in another tenant
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FolderListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_folders_with_http_info(**kwargs)  # noqa: E501

    def list_folders_with_http_info(self, **kwargs):  # noqa: E501
        """Get a list of folders  # noqa: E501

        Given a volumeId or volume name, get a list of folders accessible by the JWT. The default sort returned is alphabetical, ascending. The default page size is 10 items  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_folders_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] volume_id: Optional field that specifies comma-separated volume IDs to include in the list
        :param list[str] volume_name: Optional field that specifies comma-separated volume names to include in the list
        :param list[str] path: Optional field that specifies comma-separated paths to include in the list. Value can use wildcards (e.g. /a/b/c/*) or exact matches (e.g. /a/b/c/d/).
        :param str job_statuses: Optional field that specifies comma-separated JobStatuses to include in the list
        :param list[str] acls: Optional field that specifies comma-separated acls to include in the list
        :param bool recursive: Optional field to specify if folders should be returned recursively in and under the specified paths, or only directly in the specified paths
        :param int page_size: START_DESC END_DESC
        :param str page_token: START_DESC END_DESC
        :param str include: START_DESC END_DESC
        :param str tenant_id: Optional parameter to see shared data in another tenant
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FolderListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'volume_id',
            'volume_name',
            'path',
            'job_statuses',
            'acls',
            'recursive',
            'page_size',
            'page_token',
            'include',
            'tenant_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_folders" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'page_size' in local_var_params and local_var_params['page_size'] > 10000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_size` when calling `list_folders`, must be a value less than or equal to `10000`")  # noqa: E501
        if self.api_client.client_side_validation and 'page_size' in local_var_params and local_var_params['page_size'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_size` when calling `list_folders`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'volume_id' in local_var_params and local_var_params['volume_id'] is not None:  # noqa: E501
            query_params.append(('volume.id', local_var_params['volume_id']))  # noqa: E501
            collection_formats['volume.id'] = 'csv'  # noqa: E501
        if 'volume_name' in local_var_params and local_var_params['volume_name'] is not None:  # noqa: E501
            query_params.append(('volume.name', local_var_params['volume_name']))  # noqa: E501
            collection_formats['volume.name'] = 'csv'  # noqa: E501
        if 'path' in local_var_params and local_var_params['path'] is not None:  # noqa: E501
            query_params.append(('path', local_var_params['path']))  # noqa: E501
            collection_formats['path'] = 'csv'  # noqa: E501
        if 'job_statuses' in local_var_params and local_var_params['job_statuses'] is not None:  # noqa: E501
            query_params.append(('jobStatuses', local_var_params['job_statuses']))  # noqa: E501
        if 'acls' in local_var_params and local_var_params['acls'] is not None:  # noqa: E501
            query_params.append(('acls', local_var_params['acls']))  # noqa: E501
            collection_formats['acls'] = 'csv'  # noqa: E501
        if 'recursive' in local_var_params and local_var_params['recursive'] is not None:  # noqa: E501
            query_params.append(('recursive', local_var_params['recursive']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('pageSize', local_var_params['page_size']))  # noqa: E501
        if 'page_token' in local_var_params and local_var_params['page_token'] is not None:  # noqa: E501
            query_params.append(('pageToken', local_var_params['page_token']))  # noqa: E501
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FolderListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def unarchive_folder(self, folder_id, body, **kwargs):  # noqa: E501
        """Unarchive a folder  # noqa: E501

        Unarchive a folder from a lower storage cost tier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unarchive_folder(folder_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be unarchived. (required)
        :param FolderUnarchiveRequest body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.unarchive_folder_with_http_info(folder_id, body, **kwargs)  # noqa: E501

    def unarchive_folder_with_http_info(self, folder_id, body, **kwargs):  # noqa: E501
        """Unarchive a folder  # noqa: E501

        Unarchive a folder from a lower storage cost tier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unarchive_folder_with_http_info(folder_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be unarchived. (required)
        :param FolderUnarchiveRequest body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FolderResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unarchive_folder" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `unarchive_folder`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `unarchive_folder`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}:unarchive', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FolderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_folder(self, folder_id, **kwargs):  # noqa: E501
        """Update a folder content or acl  # noqa: E501

        Update an existing folder in GDS and return upload credentials for that folder. Changes to the folder name and other metadata are not supported at this time.  Optionally overwrite the acl for this folder if acl is provided in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_folder(folder_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be updated. (required)
        :param str include: Comma-separated list of properties to include in the response ([include=[totalItemCount]).Example: include=totalItemCount
        :param FolderUpdateRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FolderWriteableResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_folder_with_http_info(folder_id, **kwargs)  # noqa: E501

    def update_folder_with_http_info(self, folder_id, **kwargs):  # noqa: E501
        """Update a folder content or acl  # noqa: E501

        Update an existing folder in GDS and return upload credentials for that folder. Changes to the folder name and other metadata are not supported at this time.  Optionally overwrite the acl for this folder if acl is provided in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_folder_with_http_info(folder_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str folder_id: Unique identifier for the folder to be updated. (required)
        :param str include: Comma-separated list of properties to include in the response ([include=[totalItemCount]).Example: include=totalItemCount
        :param FolderUpdateRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FolderWriteableResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'folder_id',
            'include',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_folder" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and ('folder_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `update_folder`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'folder_id' in local_var_params:
            path_params['folderId'] = local_var_params['folder_id']  # noqa: E501

        query_params = []
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/folders/{folderId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FolderWriteableResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libgds
from libica.openapi.libgds.api.folders_api import FoldersApi  # noqa: E501
from libica.openapi.libgds.rest import ApiException


class TestFoldersApi(unittest.TestCase):
    """FoldersApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libgds.api.folders_api.FoldersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_folder(self):
        """Test case for archive_folder

        Archive a folder  # noqa: E501
        """
        pass

    def test_complete_folder_session(self):
        """Test case for complete_folder_session

        Complete a folder upload in GDS  # noqa: E501
        """
        pass

    def test_copy_folder(self):
        """Test case for copy_folder

        Copy a folder  # noqa: E501
        """
        pass

    def test_create_folder(self):
        """Test case for create_folder

        Create a folder in GDS and receive credentials for upload  # noqa: E501
        """
        pass

    def test_delete_folder(self):
        """Test case for delete_folder

        Deletes a folder by id  # noqa: E501
        """
        pass

    def test_get_folder(self):
        """Test case for get_folder

        Get information about a folder in GDS.  # noqa: E501
        """
        pass

    def test_get_folder_job(self):
        """Test case for get_folder_job

        Get status of a folder job in GDS  # noqa: E501
        """
        pass

    def test_get_folder_session(self):
        """Test case for get_folder_session

        Get status of a folder upload in GDS  # noqa: E501
        """
        pass

    def test_list_folders(self):
        """Test case for list_folders

        Get a list of folders  # noqa: E501
        """
        pass

    def test_unarchive_folder(self):
        """Test case for unarchive_folder

        Unarchive a folder  # noqa: E501
        """
        pass

    def test_update_folder(self):
        """Test case for update_folder

        Update a folder content or acl  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libgds
from libica.openapi.libgds.models.object_store_settings import ObjectStoreSettings  # noqa: E501
from libica.openapi.libgds.rest import ApiException

class TestObjectStoreSettings(unittest.TestCase):
    """ObjectStoreSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ObjectStoreSettings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libgds.models.object_store_settings.ObjectStoreSettings()  # noqa: E501
        if include_optional :
            return ObjectStoreSettings(
                aws_s3 = libica.openapi.libgds.models.awss3_object_store_setting.AWSS3ObjectStoreSetting(
                    bucket_name = '012', 
                    key_prefix = 'gds-volumes/', ), 
                # platform_credentials_name = '0'
                secret_name='test',
            )
        else :
            return ObjectStoreSettings(
                aws_s3 = libica.openapi.libgds.models.awss3_object_store_setting.AWSS3ObjectStoreSetting(
                    bucket_name = '012', 
                    key_prefix = 'gds-volumes/', ),
                # platform_credentials_name = '0',
                secret_name='test',
        )

    def testObjectStoreSettings(self):
        """Test ObjectStoreSettings"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libconsole
from libica.openapi.libconsole.api.accounts_api import AccountsApi  # noqa: E501
from libica.openapi.libconsole.rest import ApiException


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libconsole.api.accounts_api.AccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_account(self):
        """Test case for get_account

        Get requested account id info require authorization Bearer token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.execution import Execution  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestExecution(unittest.TestCase):
    """Execution unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Execution
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.execution.Execution()  # noqa: E501
        if include_optional :
            return Execution(
                image = libica.openapi.libtes.models.image.Image(
                    name = '0', 
                    tag = '0', 
                    digest = '0', 
                    credentials = libica.openapi.libtes.models.credentials.Credentials(
                        username = '0', 
                        password = '0', ), ), 
                command = '0', 
                args = [
                    '0'
                    ], 
                inputs = [
                    libica.openapi.libtes.models.input_mount_mapping_with_creds.InputMountMappingWithCreds(
                        storage_provider = '0', 
                        credentials = {
                            'key' : '0'
                            }, 
                        path = '0', 
                        url = '0', 
                        urn = '0', 
                        mode = '0', 
                        type = 'File', )
                    ], 
                outputs = [
                    libica.openapi.libtes.models.mount_mapping_with_creds.MountMappingWithCreds(
                        path = '0', 
                        url = '0', 
                        urn = '0', 
                        type = '0', 
                        storage_provider = '0', 
                        credentials = {
                            'key' : '0'
                            }, )
                    ], 
                system_files = libica.openapi.libtes.models.system_files.SystemFiles(
                    url = '0', 
                    urn = '0', 
                    storage_provider = '0', 
                    credentials = {
                        'key' : '0'
                        }, ), 
                environment = libica.openapi.libtes.models.environment.Environment(
                    variables = {
                        'key' : '0'
                        }, 
                    resources = libica.openapi.libtes.models.resources.Resources(
                        type = '0', 
                        size = '0', 
                        cpu_cores = 1.337, 
                        memory_gb = 1.337, 
                        hardware = [
                            '0'
                            ], 
                        tier = '0', ), 
                    input_stream_settings = libica.openapi.libtes.models.input_stream_settings.InputStreamSettings(
                        access_pattern = 'sequential', 
                        cache_size_gb = 5E+1, 
                        block_size_mb = 0, 
                        prefetch_blocks = 0, ), ), 
                working_directory = '0', 
                retry_limit = 56, 
                retry_count = 56
            )
        else :
            return Execution(
        )

    def testExecution(self):
        """Test Execution"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
